<?php

// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.


/**
 * Defines the settings for the ZiLink local
 *
 * @package     local_zilink
 * @author      Ian Tasker <ian.tasker@schoolsict.net>
 * @copyright   2010 onwards SchoolsICT Limited, UK (http://schoolsict.net)
 * @copyright   Includes sub plugins that are based on and/or adapted from other plugins please see sub plugins for credits and notices. 
 * @license     http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

require_once(dirname(__FILE__) . '/../../../../../config.php');
require_once($CFG->libdir . '/adminlib.php');
require_once(dirname(__FILE__) .'/forms/config.php');

require_login();

$context = context_system::instance();
$PAGE->set_context($context);

$urlparams = array('sesskey' => sesskey());
$url = new moodle_url($CFG->httpswwwroot.'/local/zilink/plugins/timetable/admin/index.php', $urlparams);
$PAGE->https_required();
$PAGE->set_url($CFG->httpswwwroot.'/local/zilink/plugins/timetable/admin/index.php', $urlparams);
$PAGE->verify_https_required();
$strmanage = get_string('timetable_page_title', 'local_zilink');

admin_externalpage_setup('zilink_timetable_settings',null,null,$CFG->httpswwwroot.'/local/zilink/plugins/timetable/admin/index.php');

$PAGE->set_title($strmanage);
$PAGE->set_heading($strmanage);

$PAGE->set_pagelayout('report');

$form = new zilink_timetable_settings_form(null,array(   'timetable_week_format' => $CFG->zilink_timetable_week_format,
                                                         'timetable_offset' => $CFG->zilink_timetable_offset,
                                                         'timetable_period_time_offset' => $CFG->zilink_timetable_time_offset,
                                                         'timetable_display_period_time' => $CFG->zilink_timetable_display_time,
                                                         'timetable_start_day' => $CFG->zilink_timetable_startday,
                                                         'timetable_first_week' =>  $CFG->zilink_timetable_first_week,
                                                         'timetable_room_label' => $CFG->zilink_timetable_room_label));
$fromform = $form->get_data();

if (!empty($fromform) and confirm_sesskey()) {

    if(isset($fromform->timetable_week_format))
    {
        $CFG->zilink_timetable_week_format = $fromform->timetable_week_format;
        set_config('zilink_timetable_week_format',$fromform->timetable_week_format);
    }
    
    if(isset($fromform->timetable_start_day))
    {
        $CFG->zilink_timetable_startday = $fromform->timetable_start_day;
        set_config('zilink_timetable_startday',$fromform->timetable_start_day);
    }
    
    if(isset($fromform->timetable_display_period_time))
    {
        $CFG->zilink_timetable_display_time = $fromform->timetable_display_period_time;
        set_config('zilink_timetable_display_time',$fromform->timetable_display_period_time);
    }
    
    if(isset($fromform->timetable_period_time_offset))
    {
        $CFG->zilink_timetable_time_offset = $fromform->timetable_period_time_offset;
        set_config('zilink_timetable_time_offset',$fromform->timetable_period_time_offset);
    }

    
    if(isset($fromform->timetable_offset))
    {
        $CFG->zilink_timetable_offset = $fromform->timetable_offset;
        set_config('zilink_timetable_offset',$fromform->timetable_offset);
    }

    if(isset($fromform->timetable_first_week))
    {
        $CFG->zilink_timetable_first_week = $fromform->timetable_first_week;
        set_config('zilink_timetable_first_week',$fromform->timetable_first_week);
    }

    if(isset($fromform->timetable_room_label))
    {
        $CFG->zilink_timetable_room_label = $fromform->timetable_room_label;
        set_config('zilink_timetable_room_label',$fromform->timetable_room_label);
    }
    $form->set_data($fromform); 
   
}

//OUTPUT
echo $OUTPUT->header();
echo $OUTPUT->heading(get_string('timetable_title', 'local_zilink'));
echo $OUTPUT->box(get_string('timetable_title_desc', 'local_zilink'));
echo $OUTPUT->box(get_string('timetable_support_desc', 'local_zilink').html_writer::link('http://support.schoolsict.net/hc',get_string('support_site','local_zilink'),array('target'=> '_blank')));
echo $form->display();
echo $OUTPUT->footer();

